OC.L10N.register(
    "text",
    {
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
    "No file was uploaded" : "Nulle file esseva incargate",
    "Missing a temporary folder" : "Il manca un dossier temporari",
    "Guest" : "Invitato",
    "you" : "Tu",
    "edit" : "modificar",
    "Copy link" : "Copiar ligamine",
    "guest" : "hospite",
    "Saved" : "Salveguardate",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Link" : "Ligamine",
    "Undo" : "Disfacer",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Save" : "Salveguardar",
    "Translate" : "Translate",
    "to" : "a",
    "Edit" : "Modificar",
    "Upload" : "Incargar",
    "Done" : "Preste",
    "Details" : "Detalios"
},
"nplurals=2; plural=(n != 1);");
